# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from deep_agent_sdk.api.catalog_api import CatalogApi  # noqa: E501


class TestCatalogApi(unittest.IsolatedAsyncioTestCase):
    """CatalogApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CatalogApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_skills_catalog_catalog_skills_get(self) -> None:
        """Test case for get_skills_catalog_catalog_skills_get

        List available skills  # noqa: E501
        """
        pass

    async def test_get_tools_catalog_catalog_tools_get(self) -> None:
        """Test case for get_tools_catalog_catalog_tools_get

        List available tools  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
